==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datashare/kotlin/outputs/GetSqlDWTableDataSetMappingResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datashare.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * A SQL DW Table data set mapping.
 * @property dataSetId The id of the source data set.
 * @property dataSetMappingStatus Gets the status of the data set mapping.
 * @property dataWarehouseName DataWarehouse name of the source data set
 * @property id The resource id of the azure resource
 * @property kind Kind of data set mapping.
 * Expected value is 'SqlDWTable'.
 * @property name Name of the azure resource
 * @property provisioningState Provisioning state of the data set mapping.
 * @property schemaName Schema of the table. Default value is dbo.
 * @property sqlServerResourceId Resource id of SQL server
 * @property systemData System Data of the Azure resource.
 * @property tableName SQL DW table name.
 * @property type Type of the azure resource
 */
public data class GetSqlDWTableDataSetMappingResult(
    public val dataSetId: String,
    public val dataSetMappingStatus: String,
    public val dataWarehouseName: String,
    public val id: String,
    public val kind: String,
    public val name: String,
    public val provisioningState: String,
    public val schemaName: String,
    public val sqlServerResourceId: String,
    public val systemData: SystemDataResponse,
    public val tableName: String,
    public val type: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.datashare.outputs.GetSqlDWTableDataSetMappingResult):
            GetSqlDWTableDataSetMappingResult = GetSqlDWTableDataSetMappingResult(
            dataSetId = javaType.dataSetId(),
            dataSetMappingStatus = javaType.dataSetMappingStatus(),
            dataWarehouseName = javaType.dataWarehouseName(),
            id = javaType.id(),
            kind = javaType.kind(),
            name = javaType.name(),
            provisioningState = javaType.provisioningState(),
            schemaName = javaType.schemaName(),
            sqlServerResourceId = javaType.sqlServerResourceId(),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.datashare.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            tableName = javaType.tableName(),
            type = javaType.type(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/datashare/kotlin/outputs/GetSqlDWTableDataSetMappingResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datashare.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * A SQL DW Table data set mapping.
 * @property dataSetId The id of the source data set.
 * @property dataSetMappingStatus Gets the status of the data set mapping.
 * @property dataWarehouseName DataWarehouse name of the source data set
 * @property id The resource id of the azure resource
 * @property kind Kind of data set mapping.
 * Expected value is 'SqlDWTable'.
 * @property name Name of the azure resource
 * @property provisioningState Provisioning state of the data set mapping.
 * @property schemaName Schema of the table. Default value is dbo.
 * @property sqlServerResourceId Resource id of SQL server
 * @property systemData System Data of the Azure resource.
 * @property tableName SQL DW table name.
 * @property type Type of the azure resource
 */
public data class GetSqlDWTableDataSetMappingResult(
    public val dataSetId: String,
    public val dataSetMappingStatus: String,
    public val dataWarehouseName: String,
    public val id: String,
    public val kind: String,
    public val name: String,
    public val provisioningState: String,
    public val schemaName: String,
    public val sqlServerResourceId: String,
    public val systemData: SystemDataResponse,
    public val tableName: String,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.datashare.outputs.GetSqlDWTableDataSetMappingResult): GetSqlDWTableDataSetMappingResult = GetSqlDWTableDataSetMappingResult(
            dataSetId = javaType.dataSetId(),
            dataSetMappingStatus = javaType.dataSetMappingStatus(),
            dataWarehouseName = javaType.dataWarehouseName(),
            id = javaType.id(),
            kind = javaType.kind(),
            name = javaType.name(),
            provisioningState = javaType.provisioningState(),
            schemaName = javaType.schemaName(),
            sqlServerResourceId = javaType.sqlServerResourceId(),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.datashare.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            tableName = javaType.tableName(),
            type = javaType.type(),
        )
    }
}
